API Reference
=============

.. autoclass:: say.Say
   :members:
   :special-members: __init__, __call__
   :undoc-members:
   :inherited-members:

.. autoclass:: say.Fmt
   :members:
   :special-members: __init__, __call__
   :undoc-members:
   :inherited-members:

.. autoclass:: say.Text
   :members:
   :special-members: __init__, __call__
   :undoc-members:
   :inherited-members:
